==> haskell-linear-base-0.3.0-62-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-linear-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 linear-base
version:              0.3.0
visibility:           public
id:                   linear-base-0.3.0-8MQ2h1pCDTs3Q3St5neMIS
key:                  linear-base-0.3.0-8MQ2h1pCDTs3Q3St5neMIS
license:              MIT
copyright:            (c) Tweag Holding and affiliates
maintainer:           arnaud.spiwack@tweag.io
author:               Tweag
homepage:             https://github.com/tweag/linear-base#README
synopsis:             Standard library for linear types.
description:          Please see README.md.
category:             Prelude
abi:                  e8af5d02f6872fbc389d48c97056eff9
exposed:              True
exposed-modules:
    Control.Functor.Linear Control.Functor.Linear.Internal.Class
    Control.Functor.Linear.Internal.Instances
    Control.Functor.Linear.Internal.Kan
    Control.Functor.Linear.Internal.MonadTrans
    Control.Functor.Linear.Internal.Reader
    Control.Functor.Linear.Internal.State Control.Monad.IO.Class.Linear
    Control.Optics.Linear Control.Optics.Linear.Internal
    Control.Optics.Linear.Iso Control.Optics.Linear.Lens
    Control.Optics.Linear.Prism Control.Optics.Linear.Traversal
    Data.Arity.Linear Data.Arity.Linear.Internal Data.Array.Destination
    Data.Array.Destination.Internal Data.Array.Mutable.Linear
    Data.Array.Mutable.Linear.Internal
    Data.Array.Mutable.Unlifted.Linear Data.Array.Polarized
    Data.Array.Polarized.Pull Data.Array.Polarized.Pull.Internal
    Data.Array.Polarized.Push Data.Bifunctor.Linear
    Data.Bifunctor.Linear.Internal.Bifunctor
    Data.Bifunctor.Linear.Internal.SymmetricMonoidal Data.Bool.Linear
    Data.Either.Linear Data.Functor.Linear
    Data.Functor.Linear.Internal.Applicative
    Data.Functor.Linear.Internal.Functor
    Data.Functor.Linear.Internal.Traversable
    Data.HashMap.Mutable.Linear Data.HashMap.Mutable.Linear.Internal
    Data.List.Linear Data.Maybe.Linear Data.Monoid.Linear
    Data.Monoid.Linear.Internal.Monoid
    Data.Monoid.Linear.Internal.Semigroup Data.Num.Linear
    Data.Ord.Linear Data.Ord.Linear.Internal.Eq
    Data.Ord.Linear.Internal.Ord Data.Profunctor.Kleisli.Linear
    Data.Profunctor.Linear Data.Replicator.Linear
    Data.Replicator.Linear.Internal
    Data.Replicator.Linear.Internal.Instances
    Data.Replicator.Linear.Internal.ReplicationStream
    Data.Set.Mutable.Linear Data.Set.Mutable.Linear.Internal
    Data.Tuple.Linear Data.Unrestricted.Linear
    Data.Unrestricted.Linear.Internal.Consumable
    Data.Unrestricted.Linear.Internal.Dupable
    Data.Unrestricted.Linear.Internal.Instances
    Data.Unrestricted.Linear.Internal.Movable
    Data.Unrestricted.Linear.Internal.Ur
    Data.Unrestricted.Linear.Internal.UrT Data.V.Linear
    Data.V.Linear.Internal Data.V.Linear.Internal.Instances
    Data.Vector.Mutable.Linear Data.Vector.Mutable.Linear.Internal
    Debug.Trace.Linear Foreign.Marshal.Pure
    Foreign.Marshal.Pure.Internal Prelude.Linear
    Prelude.Linear.GenericUtil Prelude.Linear.Generically
    Prelude.Linear.Internal Prelude.Linear.Internal.Generically
    Prelude.Linear.Internal.TypeEq Prelude.Linear.Unsatisfiable
    Streaming.Linear Streaming.Linear.Internal.Consume
    Streaming.Linear.Internal.Interop Streaming.Linear.Internal.Many
    Streaming.Linear.Internal.Process Streaming.Linear.Internal.Produce
    Streaming.Linear.Internal.Type Streaming.Prelude.Linear
    System.IO.Linear System.IO.Resource.Linear
    System.IO.Resource.Linear.Internal Unsafe.Linear

import-dirs:          /usr/lib/ghc-9.2.8/site-local/linear-base-0.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/linear-base-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-linear-base
hs-libraries:         HSlinear-base-0.3.0-8MQ2h1pCDTs3Q3St5neMIS
depends:
    base-4.16.4.0 containers-0.6.5.1 ghc-prim-0.8.0
    hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
    linear-generics-0.2.1-Lu9WvdvEds3H4A3qu4UgY7
    primitive-0.7.4.0-A9DQl7IN10ADdryf8HN1sF
    storable-tuple-0.1-4N4gPaP9hoUDeb399DucGT text-1.2.5.0
    transformers-0.5.6.2 vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:   /usr/share/doc/haskell-linear-base/html/linear-base.haddock
haddock-html:         /usr/share/doc/haskell-linear-base/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-linear-base-0.3.0-68-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-linear-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 linear-base
version:              0.3.0
visibility:           public
id:                   linear-base-0.3.0-4phZbEECo6dJouvWvCO5Wn
key:                  linear-base-0.3.0-4phZbEECo6dJouvWvCO5Wn
license:              MIT
copyright:            (c) Tweag Holding and affiliates
maintainer:           arnaud.spiwack@tweag.io
author:               Tweag
homepage:             https://github.com/tweag/linear-base#README
synopsis:             Standard library for linear types.
description:          Please see README.md.
category:             Prelude
abi:                  8ace64fbbdaca60585b6e18b0edb2f33
exposed:              True
exposed-modules:
    Control.Functor.Linear Control.Functor.Linear.Internal.Class
    Control.Functor.Linear.Internal.Instances
    Control.Functor.Linear.Internal.Kan
    Control.Functor.Linear.Internal.MonadTrans
    Control.Functor.Linear.Internal.Reader
    Control.Functor.Linear.Internal.State Control.Monad.IO.Class.Linear
    Control.Optics.Linear Control.Optics.Linear.Internal
    Control.Optics.Linear.Iso Control.Optics.Linear.Lens
    Control.Optics.Linear.Prism Control.Optics.Linear.Traversal
    Data.Arity.Linear Data.Arity.Linear.Internal Data.Array.Destination
    Data.Array.Destination.Internal Data.Array.Mutable.Linear
    Data.Array.Mutable.Linear.Internal
    Data.Array.Mutable.Unlifted.Linear Data.Array.Polarized
    Data.Array.Polarized.Pull Data.Array.Polarized.Pull.Internal
    Data.Array.Polarized.Push Data.Bifunctor.Linear
    Data.Bifunctor.Linear.Internal.Bifunctor
    Data.Bifunctor.Linear.Internal.SymmetricMonoidal Data.Bool.Linear
    Data.Either.Linear Data.Functor.Linear
    Data.Functor.Linear.Internal.Applicative
    Data.Functor.Linear.Internal.Functor
    Data.Functor.Linear.Internal.Traversable
    Data.HashMap.Mutable.Linear Data.HashMap.Mutable.Linear.Internal
    Data.List.Linear Data.Maybe.Linear Data.Monoid.Linear
    Data.Monoid.Linear.Internal.Monoid
    Data.Monoid.Linear.Internal.Semigroup Data.Num.Linear
    Data.Ord.Linear Data.Ord.Linear.Internal.Eq
    Data.Ord.Linear.Internal.Ord Data.Profunctor.Kleisli.Linear
    Data.Profunctor.Linear Data.Replicator.Linear
    Data.Replicator.Linear.Internal
    Data.Replicator.Linear.Internal.Instances
    Data.Replicator.Linear.Internal.ReplicationStream
    Data.Set.Mutable.Linear Data.Set.Mutable.Linear.Internal
    Data.Tuple.Linear Data.Unrestricted.Linear
    Data.Unrestricted.Linear.Internal.Consumable
    Data.Unrestricted.Linear.Internal.Dupable
    Data.Unrestricted.Linear.Internal.Instances
    Data.Unrestricted.Linear.Internal.Movable
    Data.Unrestricted.Linear.Internal.Ur
    Data.Unrestricted.Linear.Internal.UrT Data.V.Linear
    Data.V.Linear.Internal Data.V.Linear.Internal.Instances
    Data.Vector.Mutable.Linear Data.Vector.Mutable.Linear.Internal
    Debug.Trace.Linear Foreign.Marshal.Pure
    Foreign.Marshal.Pure.Internal Prelude.Linear
    Prelude.Linear.GenericUtil Prelude.Linear.Generically
    Prelude.Linear.Internal Prelude.Linear.Internal.Generically
    Prelude.Linear.Internal.TypeEq Prelude.Linear.Unsatisfiable
    Streaming.Linear Streaming.Linear.Internal.Consume
    Streaming.Linear.Internal.Interop Streaming.Linear.Internal.Many
    Streaming.Linear.Internal.Process Streaming.Linear.Internal.Produce
    Streaming.Linear.Internal.Type Streaming.Prelude.Linear
    System.IO.Linear System.IO.Resource.Linear
    System.IO.Resource.Linear.Internal Unsafe.Linear

import-dirs:          /usr/lib/ghc-9.2.8/site-local/linear-base-0.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/linear-base-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-linear-base
hs-libraries:         HSlinear-base-0.3.0-4phZbEECo6dJouvWvCO5Wn
depends:
    base-4.16.4.0 containers-0.6.5.1 ghc-prim-0.8.0
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    linear-generics-0.2.1-HBn0FbcbxJRDk1ohObOZXf
    primitive-0.7.4.0-AQ7cOoBXu5aBgAQTQzTLUx
    storable-tuple-0.1-AcUS3eMcuap4mQ6p0Lhh3O text-1.2.5.0
    transformers-0.5.6.2 vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:   /usr/share/doc/haskell-linear-base/html/linear-base.haddock
haddock-html:         /usr/share/doc/haskell-linear-base/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
